<?php

namespace WooViews;

/* This was previously the class Toolset_WooCommerce_Views from ../views-woocommerce.php. */

use WooViews\Hooks\Shortcode_Factory;
use WooViews\Hooks\Legacy_Factory;

/**
 * @codeCoverageIgnore
 */
class Bootstrap {

	public function init() {
		$this->do_init();

		add_action( 'init', array( $this, 'init_template_loader' ), - 20 );
		add_action( 'init', array( $this, 'init_settings_section' ), 0 );
		add_action( 'admin_init', array( $this, 'admin_init' ) );
		add_action( 'init', array( $this, 'register_shortcodes' ) );
		add_action( 'init', array( $this, 'register_legacy_hooks' ), 0 );
	}


	/**
	 * Init
	 */
	public function do_init() {
		global $Class_WooCommerce_Views, $WCViews_shortcodes_gui;

		// Instantiate new plugin object
		if ( ! isset( $Class_WooCommerce_Views ) ) {
			$Class_WooCommerce_Views = new \Class_WooCommerce_Views();
		}

		// Alias Functions compatible for [wpv-if].
		require WOOCOMMERCE_VIEWS_PLUGIN_PATH . '/application/Helpers/wcviews-alias-functions.php';

		// Offer to recalculate prices on plugin activation:
		// This is as simple as to add an admin notice if the woocommerce_last_run_update option is missing
		// or empty, no need to run this here...
		register_activation_hook( WC_VIEWS_FILE, array(
			$Class_WooCommerce_Views,
			'maybe_start_processing_products_fields',
		) );

		// Reset custom fields updating when deactivated.
		register_deactivation_hook( WC_VIEWS_FILE, array(
			$Class_WooCommerce_Views,
			'wcviews_request_to_reset_field_option',
		) );

		// Clear Functions inside conditional evaluations when deactivated.
		register_deactivation_hook( WC_VIEWS_FILE, array(
			$Class_WooCommerce_Views,
			'wcviews_clear_all_func_conditional_eval',
		) );

		// Shortcodes GUI.
		require WOOCOMMERCE_VIEWS_PLUGIN_PATH . '/application/Helpers/wcviews-shortcodes-gui.php';
		$WCViews_shortcodes_gui = new \WCViews_shortcodes_gui();
		$WCViews_shortcodes_gui->initialize();

		// Constants for messages.
		require WOOCOMMERCE_VIEWS_PLUGIN_PATH . '/application/Helpers/wcviews-messaging-constants.php';

		// Tooltip messages.
		require WOOCOMMERCE_VIEWS_PLUGIN_PATH . '/application/Helpers/wcviews-admin-messages.php';

		// Core Compatibility.
		require WOOCOMMERCE_VIEWS_PLUGIN_PATH . '/application/Helpers/wcviews-core-compatibility.php';
	}


	public function init_template_loader() {
		// Templates Loader
		if ( ! is_admin() ) {
			$dic = apply_filters( 'toolset_dic', false );
			$loader = $dic->make( '\WooViews\Templates\Loader' );
			add_action( 'wpv_action_after_archive_set', array( $loader, 'register_frontend_hooks' ) );
			add_action( 'template_redirect', array( $loader, 'override' ), PHP_INT_MAX );
		}
	}


	/**
	 * Admin actions
	 */
	public function admin_init() {
		// In order to make styling works in Views and WPAs previews this fake class is needed
		add_filter( 'admin_body_class', function ( $classes ) {
			return "$classes toolset-admin-woocommerce";
		} );
	}


	/**
	 * Hooks settings Frontend rendering.
	 */
	public function init_settings_section() {
		$dic = apply_filters( 'toolset_dic', false );
		if ( false === $dic ) {
			return null;
		}
		$frontend = $dic->make( '\WooViews\Settings\Frontend' );
		add_action( 'init', array( $frontend, 'init' ) );
	}


	/**
	 * Get shortcodes
	 */
	public function register_shortcodes() {
		$dic = apply_filters( 'toolset_dic', false );
		$shortcode_factory = $dic->make( Shortcode_Factory::class );
		foreach ( $shortcode_factory->create() as $shortcode ) {
			$shortcode->register();
		}
	}


	/**
	 * Legacy functionality related hooks.
	 */
	public function register_legacy_hooks() {
		$dic = apply_filters( 'toolset_dic', false );
		$legacy_factory = $dic->make( Legacy_Factory::class );
		foreach ( $legacy_factory->create() as $hook ) {
			$hook->register();
		}
	}
}
