<?php

namespace WooViews\Helpers;

/**
 * Class Template_Settings_Translator
 *
 * @package WooViews\Helpers
 */
class Template_Settings_Translator {

	/**
	 * Returns the usable string template path.
	 *
	 * @param array $path_array Stored template settings array.
	 *
	 * @return string|null
	 */
	public function get_usable_template_path( $path_array = [] ) {
		if ( is_array( $path_array ) ) {
			$current_theme = get_stylesheet();
			if (
				isset( $path_array[ $current_theme ] )
				&& file_exists( $path_array[ $current_theme ] )
			) {
				return $path_array[ $current_theme ];
			}
		}

		return null;
	}


	/**
	 * Check if the provided template path belongs to a theme.
	 *
	 * @param string|null $template_path
	 *
	 * @return bool
	 */
	public function is_theme_template( $template_path ) {
		if ( null === $template_path ) {
			return false;
		}

		$theme_path = get_stylesheet_directory();
		return str_contains( $template_path, $theme_path );
	}
}
