<?php

namespace WooViews\Hooks\Frontend;

use WooViews\Hooks\IHook;
use WooViews\Settings\Persistence\Models\Global_Settings;
use WooViews\Templates\Modes\IMode;
use WooViews\Templates\Types;

/**
 * Class Woo_GUI_Elements
 *
 * @package WooViews\Hooks\Frontend
 */
class Woo_GUI_Elements implements IHook {

	/**
	 * @var IMode
	 */
	private $mode;

	/**
	 * @var Global_Settings
	 */
	private $settings;


	/**
	 * Woo_GUI_Elements constructor.
	 *
	 * @param IMode $mode
	 * @param Global_Settings $settings
	 */
	public function __construct( IMode $mode, Global_Settings $settings ) {
		$this->mode = $mode;
		$this->settings = $settings;
	}


	/**
	 * Registers the hook
	 */
	public function register() {
		$this->define();
	}


	/**
	 * Removes the woocommerce gui hooks if the mode type is WCB.
	 */
	public function define() {
		// If the loaded template mode is WCB remove all WooCommerce GUI elements.
		if ( $this->mode->get_type() === Types::WCB && $this->settings->get_frontend_sorting_enabled() === false ) {
			$override_sorting = apply_filters( 'woocommerce_views_override_woo_sorting_settings', false );

			if ( ! $override_sorting ) {
				remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
			}

			$override_pagination = apply_filters( 'woocommerce_views_override_woo_pagination_settings', false );
			if ( ! $override_pagination ) {
				remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
				remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination' );
			}
		}
	}
}
