<?php

namespace WooViews\Hooks\Frontend;

use WooViews\Hooks\IHook;
use WooViews\Settings\Persistence\Models\Global_Settings;
use WooViews\Templates\Modes\IMode;
use WooViews\Templates\Types;

/**
 * Class Woo_Sorting
 *
 * @package WooViews\Hooks\Frontend
 */
class Woo_Sorting implements IHook {

	/**
	 * @var Global_Settings
	 */
	private $settings;

	/**
	 * @var IMode
	 */
	private $mode;


	/**
	 * Woo_Sorting constructor.
	 *
	 * @param Global_Settings $settings
	 * @param IMode $mode
	 */
	public function __construct( Global_Settings $settings, IMode $mode ) {
		$this->settings = $settings;
		$this->mode = $mode;
	}


	/**
	 * Registers the hook
	 */
	public function register() {
		$this->define();
	}


	/**
	 * Removes the WPV query hooks if woocommerce frontend sorting is enabled
	 */
	public function define() {
		// If the legacy setting for WooCommerce frontend sorting is enabled.
		// Remove the Views ordering hook.
		if ( $this->mode->get_type() !== Types::WCB && $this->settings->get_frontend_sorting_enabled() === true ) {
			global $WPV_view_archive_loop;
			remove_action( 'wpv_action_apply_archive_query_settings', array(
				$WPV_view_archive_loop,
				'archive_apply_order_settings',
			), 20 );
		}
	}
}
