<?php

namespace WooViews\Hooks\Legacy;

use WooViews\Hooks\IHook;
use WooViews\Settings\Persistence\Models\Global_Settings;

/**
 * Class Remove_Sorting_Fields
 *
 * @package WooViews\Hooks\Legacy
 */
class Remove_Sorting_Fields implements IHook {

	/**
	 * @var Global_Settings
	 */
	private $settings;


	/**
	 * Remove_Sorting_Fields constructor.
	 *
	 * @param Global_Settings $settings
	 */
	public function __construct( Global_Settings $settings ) {
		$this->settings = $settings;
	}


	/**
	 * @return void
	 */
	public function register() {
		add_action( 'wp_loaded', [ $this, 'define' ] );
		add_filter( 'woocommerce_views_removed_legacy_sorting_field', [
			$this,
			'filter_removed_legacy_sorting_field',
		] );
	}


	/**
	 * Deactivates legacy Woocommerce filter fields group.
	 *
	 * @return null
	 */
	public function define() {
		if ( $this->settings->get_removed_legacy_sorting_fields() ) {
			return;
		}

		$field_groups = apply_filters( 'types_query_groups', null, [
			'domain' => 'posts',
			'types_search' => 'WooCommerce Views filter fields',
		] );

		if ( empty( $field_groups ) || ! is_array( $field_groups ) ) {
			return null;
		}

		$group = reset( $field_groups );
		if ( ! $group->is_active( false ) ) {
			$this->settings->set_removed_legacy_sorting_fields( true );
		}

	}


	/**
	 * @param boolean $removed
	 *
	 * @return boolean
	 */
	public function filter_removed_legacy_sorting_field( $removed = false ) {
		return $this->settings->get_removed_legacy_sorting_fields();
	}
}
