<?php

namespace WooViews\Settings\Persistence\Models;

class Global_Settings extends AModel {

	/**
	 * @param bool $value
	 *
	 * @return bool
	 */
	public function set_frontend_sorting_enabled( $value ) {
		$value = rest_sanitize_boolean( $value );
		if ( is_bool( $value ) ) {
			$mapped_value = $this->map_bool_to_yes_no( $value );

			return update_option( 'woocommerce_views_frontend_sorting_setting', $mapped_value );
		}

		return false;
	}


	/**
	 * @return bool
	 */
	public function get_frontend_sorting_enabled() {
		return $this->map_yes_no_to_bool( get_option( 'woocommerce_views_frontend_sorting_setting' ) );
	}


	/**
	 * @param bool $value
	 *
	 * @return bool
	 */
	public function set_use_woocommerce_styling( $value ) {
		$value = rest_sanitize_boolean( $value );
		if ( is_bool( $value ) ) {
			$mapped_value = $this->map_bool_to_yes_no( $value );

			return update_option( 'woocommerce_views_wrap_the_content', $mapped_value );
		}

		return false;
	}


	/**
	 * @return bool
	 */
	public function get_use_woocommerce_styling() {
		return $this->map_yes_no_to_bool( get_option( 'woocommerce_views_wrap_the_content', 'yes' ) );
	}


	/**
	 * Returns the single template path array.
	 *
	 * @return array
	 */
	public function get_template_path() {
		return get_option( 'woocommerce_views_theme_template_file' );
	}


	/**
	 * @return bool
	 */
	public function get_removed_legacy_sorting_fields() {
		return (bool) get_option( 'woocommerce_views_removed_sorting_fields' );
	}


	/**
	 * Returns the archive template path array.
	 *
	 * @return array
	 */
	public function get_archive_template_path() {
		return get_option( 'woocommerce_views_theme_archivetemplate_file' );
	}


	/**
	 * Deletes the legacy templates path options.
	 */
	public function clean_template_path_options() {
		delete_option( 'woocommerce_views_theme_archivetemplate_file' );
		delete_option( 'woocommerce_views_theme_template_file' );
	}


	/**
	 * @param bool $value
	 *
	 * @return mixed
	 */
	public function set_removed_legacy_sorting_fields( $value ) {
		return update_option( 'woocommerce_views_removed_sorting_fields', (bool) $value );
	}
}
