<?php

namespace WooViews\Settings\Sections;

use WooViews\Frontend\IRenderer;
use WooViews\Settings\Persistence\Models\Global_Settings;

/**
 * Class ASection
 *
 * @package WooViews\Settings\Sections
 */
abstract class ASection implements ISection {

	const SECTIONS_VIEWS_PATH = 'settings/sections/';

	/**
	 * Section slug.
	 *
	 * @var string
	 */
	protected $slug;

	/**
	 * Section title.
	 *
	 * @var string
	 */
	protected $title;

	/**
	 * @var Global_Settings
	 */
	protected $settings;

	/**
	 * @var IRenderer
	 */
	protected $renderer;


	/**
	 * ASection constructor.
	 *
	 * @param Global_Settings $settings
	 * @param IRenderer $renderer
	 */
	public function __construct( Global_Settings $settings, IRenderer $renderer ) {
		$this->settings = $settings;
		$this->renderer = $renderer;
	}


	/**
	 * Registers the section.
	 *
	 * @param $sections
	 *
	 * @return mixed
	 */
	public function register( $sections ) {
		$sections[ $this->slug ] = [
			'slug' => $this->slug,
			'title' => $this->title,
			'content' => $this->render(),
		];

		return $sections;
	}


	/**
	 * Returns rendered html.
	 *
	 * @return string
	 */
	public function render() {
		return $this->renderer->render( self::SECTIONS_VIEWS_PATH . $this->slug, $this->settings );
	}


	/**
	 * Returns whether a section is enabled.
	 *
	 * @return bool
	 */
	public function is_enabled() {
		return true;
	}
}
