<?php

namespace WooViews\Settings\Sections;

use WooViews\Frontend\IRenderer;
use WooViews\Settings\Persistence\Models\Global_Settings;

/**
 * Class FE_Sorting
 *
 * @package WooViews\Settings\Sections
 */
class FE_Sorting extends ASection {

	/**
	 * Section slug.
	 *
	 * @var string
	 */
	protected $slug = 'fe-sorting';


	/**
	 * FE_Sorting constructor.
	 *
	 * @param Global_Settings $settings
	 * @param IRenderer $renderer
	 */
	public function __construct( Global_Settings $settings, IRenderer $renderer ) {
		parent::__construct( $settings, $renderer );

		$this->title = __( 'Front-end Sorting', 'woocommerce-views' );
	}


	/**
	 * Returns rendered html string.
	 *
	 * @return string
	 */
	public function render() {
		return $this->renderer->render( self::SECTIONS_VIEWS_PATH . $this->slug, [
			'frontend_sorting_enabled' => $this->settings->get_frontend_sorting_enabled(),
		] );
	}


	/**
	 * The section is only enabled if an old user had the option set to true.
	 *
	 * @return bool
	 */
	public function is_enabled() {
		return $this->settings->get_frontend_sorting_enabled();
	}

}
