<?php

namespace WooViews\Settings\Sections;

use WooViews\Frontend\IRenderer;
use WooViews\Helpers\Template_Settings_Translator;
use WooViews\Settings\Persistence\Models\Global_Settings;

class Legacy_Templates extends ASection {

	/**
	 * Section slug.
	 *
	 * @var string
	 */
	protected $slug = 'legacy-templates';

	/**
	 * @var Template_Settings_Translator
	 */
	private $template_helper;


	/**
	 * WC_Styling constructor.
	 *
	 * @param Global_Settings $settings
	 * @param IRenderer $renderer
	 */
	public function __construct( Global_Settings $settings, IRenderer $renderer, Template_Settings_Translator $template_helper ) {
		parent::__construct( $settings, $renderer );

		$this->title = __( 'Loaded Templates', 'woocommerce-views' );
		$this->template_helper = $template_helper;
	}


	/**
	 * Renders the section.
	 *
	 * @return string
	 */
	public function render() {
		$archive_template_path = $this->get_archive_template_path();
		$single_template_path = $this->get_template_path();

		return $this->renderer->render( self::SECTIONS_VIEWS_PATH . $this->slug, [
			'single_template_path' => $single_template_path,
			'archive_template_path' => $archive_template_path,
			'is_theme_archive' => $this->template_helper->is_theme_template( $archive_template_path ),
			'is_theme_single' => $this->template_helper->is_theme_template( $single_template_path ),
			'nonce_field' => $this->nonce_field(),
			'theme_name' => $this->theme_name()
		] );
	}


	/**
	 * Returns enable status.
	 *
	 * @return bool
	 */
	public function is_enabled() {
		return $this->template_helper->is_theme_template( $this->get_template_path() )
			|| $this->template_helper->is_theme_template( $this->get_archive_template_path() );
	}


	/**
	 *
	 * Gets the usable single template path.
	 *
	 * @return string|null
	 */
	private function get_template_path() {
		$saved_path = $this->settings->get_template_path();

		return $this->template_helper->get_usable_template_path( $saved_path );

	}


	/**
	 * Gets the usable archive template path.
	 *
	 * @return string|null
	 */
	private function get_archive_template_path() {
		$saved_path = $this->settings->get_archive_template_path();

		return $this->template_helper->get_usable_template_path( $saved_path );
	}


	/**
	 * Nonce field.
	 *
	 * @return string
	 */
	private function nonce_field() {
		return wp_nonce_field( 'woo_blocks_switch_templates', 'wcb_switch_templates_nonce', false, false );
	}


	/**
	 * @return string
	 */
	private function theme_name() {
		return wp_get_theme()->get('Name');
	}
}
