<?php

namespace WooViews\Settings\Sections;

use WooViews\Frontend\IRenderer;
use WooViews\Settings\Persistence\Models\Global_Settings;

/**
 * Class WC_Styling
 *
 * @package WooViews\Settings\Sections
 */
class WC_Styling extends ASection {

	/**
	 * Section slug.
	 *
	 * @var string
	 */
	protected $slug = 'wc-styling';


	/**
	 * WC_Styling constructor.
	 *
	 * @param Global_Settings $settings
	 * @param IRenderer $renderer
	 */
	public function __construct( Global_Settings $settings, IRenderer $renderer ) {
		parent::__construct( $settings, $renderer );

		$this->title = __( 'WooCommerce Styling', 'woocommerce-views' );
	}


	/**
	 * Returns a nonce field html string.
	 *
	 * @return string
	 */
	private function nonce_field() {
		return wp_nonce_field( 'woo_blocks_store_settings', 'wcb_settings_nonce', false, false );
	}


	/**
	 * Returns rendered html string.
	 *
	 * @return string
	 */
	public function render() {
		return $this->renderer->render( self::SECTIONS_VIEWS_PATH . $this->slug, [
			'use_woocommerce_styling' => $this->settings->get_use_woocommerce_styling(),
			'nonce_field' => $this->nonce_field(),
		] );
	}
}
