<?php

namespace WooViews\Templates;

use WooViews\Templates\Modes\Coordinator as Modes_Coordinator;
use WooViews\Hooks\Frontend_Factory as Hooks_Factory;

/**
 * Class Loader
 *
 * @package WooViews\Templates
 */
class Loader {

	/**
	 * @var Factory
	 */
	private $template_factory;

	/**
	 * @var Modes_Coordinator
	 */
	private $modes_coordinator;


	/**
	 * @var Hooks_Factory
	 */
	private $hooks_factory;


	/**
	 * Loader constructor.
	 *
	 * @param Factory $template_factory
	 * @param Modes_Coordinator $modes_coordinator
	 * @param Hooks_Factory $hooks_factory
	 */
	public function __construct( Factory $template_factory, Modes_Coordinator $modes_coordinator, Hooks_Factory $hooks_factory ) {
		$this->template_factory = $template_factory;
		$this->modes_coordinator = $modes_coordinator;
		$this->hooks_factory = $hooks_factory;
	}


	/**
	 * Hooks on template_redirect , it determines and loads the correct template file for both single products and
	 * product archives.
	 */
	public function override() {
		// Single product template loading.
		if ( is_single() && is_product() ) {
			$mode = $this->modes_coordinator->get_mode();
			$this->load( $this->template_factory->create( $mode->get_type() )->get_single_path() );
		}

		// Product archive template loading.
		if ( $this->is_product_archive() ) {
			$mode = $this->modes_coordinator->get_mode( Types::ARCHIVE );
			$this->load( $this->template_factory->create( $mode->get_type() )->get_archive_path() );
		}
	}


	/**
	 * Register related frontend hooks.
	 */
	public function register_frontend_hooks() {
		if ( is_product() || $this->is_product_archive() ) {
			$mode = $this->modes_coordinator->get_mode( $this->is_product_archive() ? Types::ARCHIVE : Types::SINGLE );
			foreach ( $this->hooks_factory->create( $mode ) as $hook ) {
				$hook->register();
			}
		}
	}


	/**
	 * Includes the template file then terminates php execution.
	 *
	 * @param string $path
	 */
	private function load( $path ) {
		if ( ! empty( $path ) ) {
			include_once $path;
			exit();
		}
	}


	/**
	 * Checks if the page being loaded is a product archive.
	 *
	 * @return bool
	 */
	private function is_product_archive() {
		return is_shop() || is_product_category() || is_product_taxonomy() || is_product_tag();
	}

}
