<?php

namespace WooViews\Templates\Modes;

use WooViews\Templates\Types;

class Coordinator {

	/**
	 * @var WCB
	 */
	private $wcb_mode;

	/**
	 * @var Theme
	 */
	private $theme_mode;

	/**
	 * @var Woo
	 */
	private $woo_mode;


	/**
	 * Coordinator constructor.
	 *
	 * @param WCB $wcb_mode
	 * @param Theme $theme_mode
	 */
	public function __construct( WCB $wcb_mode, Theme $theme_mode, Woo $woo_mode ) {
		$this->wcb_mode = $wcb_mode;
		$this->theme_mode = $theme_mode;
		$this->woo_mode = $woo_mode;
	}


	/**
	 * Returns Template mode to be used in template loading.
	 *
	 * @param string $template_type
	 *
	 * @return IMode
	 */
	public function get_mode( $template_type = Types::SINGLE ) {
		if ( $this->theme_mode->is_loadable( $template_type ) ) {
			return $this->theme_mode;
		}

		if ( $this->wcb_mode->is_loadable( $template_type ) ) {
			return $this->wcb_mode;
		}

		return $this->woo_mode;
	}
}
