<?php

namespace WooViews\Templates\Modes;

use WooViews\Helpers\Template_Settings_Translator;
use WooViews\Settings\Persistence\Models\Global_Settings;
use WooViews\Templates\Types;

class Theme implements IMode {

	/**
	 * @var Global_Settings
	 */
	private $settings;

	/**
	 * @var Template_Settings_Translator
	 */
	private $settings_translator;


	/**
	 * Theme constructor.
	 *
	 * @param Global_Settings $settings
	 * @param Template_Settings_Translator $settings_translator
	 */
	public function __construct( Global_Settings $settings, Template_Settings_Translator $settings_translator ) {
		$this->settings = $settings;
		$this->settings_translator = $settings_translator;
	}


	/**
	 * @param string $template
	 *
	 * @return bool
	 */
	public function is_loadable( $template = Types::SINGLE ) {
		switch ( $template ) {
			case Types::SINGLE:
				return $this->has_theme_single_template();
			case Types::ARCHIVE;
				return $this->has_theme_archive_template();
			default:
				return false;
		}
	}


	/**
	 * Status of a theme having a dedicated single-product template for woocommerce.
	 *
	 * @return bool
	 */
	private function has_theme_single_template() {
		return ! empty( $this->settings_translator->get_usable_template_path( $this->settings->get_template_path() ) );
	}


	/**
	 * Status of a theme having a dedicated archive-product template for woocommerce.
	 *
	 * @return bool
	 */
	private function has_theme_archive_template() {
		return ! empty( $this->settings_translator->get_usable_template_path( $this->settings->get_archive_template_path() ) );
	}


	/**
	 * @param string $type
	 *
	 * @return null
	 */
	public function get_assigned_resource( $type ) {
		return null;
	}


	/**
	 * Get mode template type
	 *
	 * @return string
	 */
	public function get_type() {
		return Types::THEME;
	}
}
