<?php

namespace WooViews\Templates\Modes;

use WooViews\Templates\Types;

class WCB implements IMode {

	private $ct_id;
	private $wpa_id;

	public function is_loadable( $template = Types::SINGLE ) {
		switch ( $template ) {
			case Types::SINGLE:
				return $this->has_single_resource();
			case Types::ARCHIVE;
				return $this->has_archive_resource();
			default:
				return false;
		}
	}

	/**
	 * Status of single resource being assigned to product post type.
	 *
	 * @return bool
	 */
	private function has_single_resource() {
		if ( $this->has_views_ct() ) {
			return true;
		}

		return $this->has_legacy_layout();
	}

	/**
	 * Status of archive resource being assigned to product post type.
	 *
	 * @return bool
	 */
	private function has_archive_resource() {
		if ( $this->has_views_archive() ) {
			return true;
		}

		return $this->has_legacy_layout();
	}


	/**
	 * Status of content template being assigned to product post type.
	 *
	 * @return bool
	 */
	private function has_views_ct() {
		if ( ! function_exists( 'has_wpv_content_template' ) ) {
			return false;
		}
		$post_id = get_the_ID();

		return has_wpv_content_template( $post_id ) !== 0;
	}


	/**
	 * Status of a views WPA being assigned to product post type.
	 *
	 * @return bool
	 */
	private function has_views_archive() {
		if ( ! function_exists( 'has_wpv_wp_archive' ) ) {
			return false;
		}

		return has_wpv_wp_archive( 'post', 'product' ) !== 0;
	}


	/**
	 * Status of a layout being assigned to the current single/archive for products.
	 *
	 * @return bool
	 */
	private function has_legacy_layout() {
		if ( ! function_exists( 'is_ddlayout_assigned' ) ) {
			return false;
		}

		return (bool) is_ddlayout_assigned();
	}


	/**
	 * @param string $type
	 *
	 * @return mixed|null
	 */
	public function get_assigned_resource( $type ) {
		switch ( $type ) {
			case Types::SINGLE:
				return $this->ct_id;
			case Types::ARCHIVE:
				return $this->wpa_id;
			default:
				return null;
		}
	}


	/**
	 * Get mode template type
	 *
	 * @return string
	 */
	public function get_type() {
		return Types::WCB;
	}
}
